#!/usr/bin/python
'''
Atom entry parser example using SimpleParse. This is not a 100% feature
complete parser for this format (see atomtest.py for something that is closer
to that). This is just an example of how this can help build applications that
use XML very quickly.

More information about the Atom format:

http://atomenabled.org/developers/syndication/
'''

import simplexmlparse
import xml.dom.minidom as minidom

# This template was directly hacked from the example on the website
TEMPLATE="""
<entry xmlns="http://www.w3.org/2005/Atom" xmlns:simplexmlparse="http://evanjones.ca/simplexmlparse">
    <title simplexmlparse:count="1">Atom-Powered Robots Run Amok</title>
    <link href="required URI"/>
    <id simplexmlparse:count="1">urn:uuid:1225c695-cfb8-4ebb-aaaa-80da344efa6a</id>
    <updated simplexmlparse:count="1">2003-12-13T18:30:02Z</updated>
    <summary>Some text.</summary>
</entry>
"""

GOOD_DOCUMENT="""
<entry xmlns="http://www.w3.org/2005/Atom">
    <title>Atom-Powered Robots Run Amok</title>
    <link href="http://example.org/2003/12/13/atom03"/>
    <id>urn:uuid:1225c695-cfb8-4ebb-aaaa-80da344efa6a</id>
    <updated>2003-12-13T18:30:02Z</updated>
    <summary>Some text.</summary>
</entry>
"""

MISSING_ID="""
<entry xmlns="http://www.w3.org/2005/Atom">
    <title>This document will fail to parse: it is missing an ID element</title>
    <link href="http://example.org/2003/12/13/atom03"/>
    <updated>2003-12-13T18:30:02Z</updated>
</entry>
"""

MULTIPLE_IDS="""
<entry xmlns="http://www.w3.org/2005/Atom">
    <title>This document will fail to parse: it has multiple IDs</title>
    <id>urn:uuid:99999999-cfb8-4ebb-aaaa-80da344efa6a</id>
    <link href="http://example.org/2003/12/13/atom03"/>
    <updated>2003-12-13T18:30:02Z</updated>
    <id>urn:uuid:1225c695-cfb8-4ebb-aaaa-80da344efa6a</id>
</entry>
"""

def parseAtomEntry( text ):
	parser = simplexmlparse.SimpleXMLParser( TEMPLATE )
	entry = parser.parse( text )

	print "\ttitle =", entry.title._text
	print "\tid =", entry.id._text
	print "\tupdated =", entry.updated._text
	if entry.summary: print "\tsummary =", entry.summary._text
	if entry.link: print "\tlink href =", entry.link.href

def domParseAtomEntry( text ):
	dom = minidom.parseString( text )
	print "\ttitle =", dom.firstChild.getElementsByTagName( 'title' )[0].firstChild.data
	print "\tid =", dom.firstChild.getElementsByTagName( 'id' )[0].firstChild.data
	print "\tupdated =", dom.firstChild.getElementsByTagName( 'updated' )[0].firstChild.data
	
	summaries = dom.firstChild.getElementsByTagName( 'summary' )
	if len( summaries ) > 0: print "\tsummary =", summaries[0].firstChild.data
	
	links = dom.firstChild.getElementsByTagName( 'link' )
	if len( links ) > 0:
		print "\tlink href =", links[0].getAttribute( 'href' )



print "Good document:"
parseAtomEntry( GOOD_DOCUMENT )
print

print "Missing ID:"
try:
	parseAtomEntry( MISSING_ID )
except simplexmlparse.ParseError, e:
	print "\tParseError:", e
else:
	assert( False )
print

print "Multiple IDs:"
try:
	parseAtomEntry( MULTIPLE_IDS )
except simplexmlparse.ParseError, e:
	print "\tParseError:", e
else:
	assert( False )
print

print "DOM Parsing:"
domParseAtomEntry( GOOD_DOCUMENT )
print

print "DOM Parsing Missing ID:"
domParseAtomEntry( MISSING_ID )
print
